@@ -207,7 +207,7 @@ impl Stivale2StructTagTerminal {
     /// print("Hello world");
     ///
     /// ```
-    pub fn get_term_write(&mut self) -> impl Fn(&str) {
+    pub fn get_term_write(&self) -> impl Fn(&str) {
         type Stivale2TermWrite = extern "C" fn(*const i8, u64);
 
         let _func = unsafe {
